package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.DiyCity;

/**
 * 自定义地区Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IDiyCityService 
{
    /**
     * 查询自定义地区
     * 
     * @param id 自定义地区主键
     * @return 自定义地区
     */
    public DiyCity selectDiyCityById(Integer id);

    /**
     * 查询自定义地区列表
     * 
     * @param diyCity 自定义地区
     * @return 自定义地区集合
     */
    public List<DiyCity> selectDiyCityList(DiyCity diyCity);

    /**
     * 新增自定义地区
     * 
     * @param diyCity 自定义地区
     * @return 结果
     */
    public int insertDiyCity(DiyCity diyCity);

    /**
     * 修改自定义地区
     * 
     * @param diyCity 自定义地区
     * @return 结果
     */
    public int updateDiyCity(DiyCity diyCity);

    /**
     * 批量删除自定义地区
     * 
     * @param ids 需要删除的自定义地区主键集合
     * @return 结果
     */
    public int deleteDiyCityByIds(Integer[] ids);

    /**
     * 删除自定义地区信息
     * 
     * @param id 自定义地区主键
     * @return 结果
     */
    public int deleteDiyCityById(Integer id);
}
